@@ -1,5 +1,3 @@
-extern crate plotlib;
-
 use plotlib::style::Point;
 
 fn main() {
@@ -11,22 +9,24 @@ fn main() {
         (6.4, 4.3),
         (8.5, 3.7),
     ];
-    let s1 = plotlib::scatter::Scatter::from_vec(&data).style(
+    let s1 = plotlib::scatter::Scatter::from_slice(&data).style(
         plotlib::scatter::Style::new()
             .marker(plotlib::style::Marker::Square)
-            .colour("#DD3355")
+            .colour("burlywood")
             .size(2.),
     );
-    let s2 = plotlib::scatter::Scatter::from_vec(&[(-1.4, 2.5), (7.2, -0.3)])
-        .style(plotlib::scatter::Style::new().colour("#35C788"));
-    let v = plotlib::view::View::new()
+    let s2 = plotlib::scatter::Scatter::from_slice(&[(-1.4, 2.5), (7.2, -0.3)])
+        .style(plotlib::scatter::Style::new().colour("darkseagreen"));
+    let v = plotlib::view::ContinuousView::new()
         .add(&s1)
         .add(&s2)
         .x_range(-5., 10.)
         .y_range(-2., 6.)
         .x_label("Some varying variable")
         .y_label("The response of something");
-    plotlib::page::Page::single(&v).save("scatter.svg");
+    plotlib::page::Page::single(&v)
+        .save("scatter.svg")
+        .expect("saving svg");
 
     /*
     //
@@ -53,7 +53,7 @@ fn main() {
     let g = Grid::new();
 
     // Create a view containing all the representations
-    let v = View::new()
+    let v = ContinuousView::new()
         .add(&l)
         .add(&h)
         .add(&s)
@@ -82,7 +82,7 @@ fn main() {
         .alpha(0.3)
         .fill(true;
 
-    let v = View::new()
+    let v = ContinuousView::new()
         .add(y1)
         .add(y2);
 
