@@ -2,7 +2,17 @@
 
 # plotlib
 
-plotlib is a data plotting and rendering library/
+plotlib is a data plotting and rendering library.
+
+## Usage
+
+There are five different types of plot currently supported:
+
+1. Box plot (`plotlib::boxplot::Box`)
+1. Function (`plotlib::function::Function`)
+1. Histogram (`plotlib::histogram::Histogram`)
+1. Line chart (`plotlib::line::Line`)
+1. Scatter plot (`plotlib::scatter::Scatter`)
 
 ## Technical
 
@@ -16,7 +26,7 @@ Five main components of the plotlib pipeline:
 
 **Data** is the plain Rust data structure that the user brings along.
 This might be something like a `Vec`, an `ndarray` or a slice.
-This will likely be copied or moved from to contruct the *representation*.
+This will likely be copied or moved from to construct the *representation*.
 
 The **representation** is the transformed version of that data which is the base plot object.
 Each representation has N dimensions of input and one dimension of output.
@@ -40,7 +50,7 @@ A **page** is the whole page. It can contain multiple views and specifies how th
 
 Finally the **rendering** is the actual output.
 This could be an SVG, a PNG, an ASCII plot or an interactive web page.
-A rendering will not necessarilly be able to show all types of views or representations
+A rendering will not necessarily be able to show all types of views or representations
 and may choose to ignore some.
 
 This structure allows some data set to be represented multiple ways in one view
@@ -65,17 +75,20 @@ in this case, interpreting the bins and colours to create SVG elements.
 
 */
 
-extern crate svg;
-
-mod representation;
-pub mod view;
 pub mod page;
+pub mod representation;
+pub mod view;
 
-pub mod histogram;
-pub mod scatter;
-pub mod function;
-pub mod style;
 mod axis;
-mod utils;
-mod text_render;
+pub mod barchart;
+pub mod boxplot;
+mod errors;
+pub mod function;
+pub mod grid;
+pub mod histogram;
+pub mod line;
+pub mod scatter;
+pub mod style;
 mod svg_render;
+mod text_render;
+mod utils;
