@@ -2,11 +2,11 @@ use std::f64;
 
 use svg;
 
-use axis;
-use svg_render;
-use text_render;
-use representation::Representation;
-use style;
+use crate::axis;
+use crate::representation::ContinuousRepresentation;
+use crate::style;
+use crate::svg_render;
+use crate::text_render;
 
 /// `Style` follows the 'optional builder' pattern
 /// Each field is a `Option` which start as `None`
@@ -38,8 +38,8 @@ impl Style {
             self.colour = Some(v.clone())
         }
 
-        if let Some(ref v) = other.size {
-            self.size = Some(v.clone())
+        if let Some(v) = other.size {
+            self.size = Some(v)
         }
     }
 }
@@ -91,14 +91,14 @@ pub struct Scatter {
 }
 
 impl Scatter {
-    pub fn from_vec(v: &[(f64, f64)]) -> Self {
+    pub fn from_slice(v: &[(f64, f64)]) -> Self {
         let mut data: Vec<(f64, f64)> = vec![];
         for &(x, y) in v {
             data.push((x, y));
         }
 
         Scatter {
-            data: data,
+            data,
             style: Style::new(),
         }
     }
@@ -133,7 +133,7 @@ impl Scatter {
     }
 }
 
-impl Representation for Scatter {
+impl ContinuousRepresentation for Scatter {
     fn range(&self, dim: u32) -> (f64, f64) {
         match dim {
             0 => self.x_range(),
@@ -144,21 +144,35 @@ impl Representation for Scatter {
 
     fn to_svg(
         &self,
-        x_axis: &axis::Axis,
-        y_axis: &axis::Axis,
+        x_axis: &axis::ContinuousAxis,
+        y_axis: &axis::ContinuousAxis,
         face_width: f64,
         face_height: f64,
     ) -> svg::node::element::Group {
-        svg_render::draw_face_points(self, x_axis, y_axis, face_width, face_height, &self.style)
+        svg_render::draw_face_points(
+            &self.data,
+            x_axis,
+            y_axis,
+            face_width,
+            face_height,
+            &self.style,
+        )
     }
 
     fn to_text(
         &self,
-        x_axis: &axis::Axis,
-        y_axis: &axis::Axis,
+        x_axis: &axis::ContinuousAxis,
+        y_axis: &axis::ContinuousAxis,
         face_width: u32,
         face_height: u32,
     ) -> String {
-        text_render::render_face_points(self, x_axis, y_axis, face_width, face_height, &self.style)
+        text_render::render_face_points(
+            &self.data,
+            x_axis,
+            y_axis,
+            face_width,
+            face_height,
+            &self.style,
+        )
     }
 }
