@@ -55,3 +55,19 @@ pub trait Bar {
 
     fn get_fill(&self) -> &Option<String>;
 }
+
+pub trait BoxPlot {
+    fn fill<T>(&mut self, value: T) -> &mut Self
+    where
+        T: Into<String>;
+
+    fn get_fill(&self) -> &Option<String>;
+}
+
+pub trait BarChart {
+    fn fill<T>(&mut self, value: T) -> &mut Self
+    where
+        T: Into<String>;
+
+    fn get_fill(&self) -> &Option<String>;
+}
