@@ -1,18 +1,17 @@
 //! A module for plotting graphs
 
-use std::collections::HashMap;
 use std;
+use std::collections::HashMap;
 
-use histogram;
-use scatter;
-use axis;
-use utils::PairWise;
-use style;
+use crate::axis;
+use crate::histogram;
+use crate::style;
+use crate::utils::PairWise;
 
 // Given a value like a tick label or a bin count,
 // calculate how far from the x-axis it should be plotted
-fn value_to_axis_cell_offset(value: f64, axis: &axis::Axis, face_cells: u32) -> i32 {
-    let data_per_cell = (axis.max() - axis.min()) / face_cells as f64;
+fn value_to_axis_cell_offset(value: f64, axis: &axis::ContinuousAxis, face_cells: u32) -> i32 {
+    let data_per_cell = (axis.max() - axis.min()) / f64::from(face_cells);
     ((value - axis.min()) / data_per_cell).round() as i32
 }
 
@@ -20,7 +19,7 @@ fn value_to_axis_cell_offset(value: f64, axis: &axis::Axis, face_cells: u32) ->
 /// the total scale of the axis
 /// and the number of face cells to work with,
 /// create a mapping of cell offset to tick value
-fn tick_offset_map(axis: &axis::Axis, face_width: u32) -> HashMap<i32, f64> {
+fn tick_offset_map(axis: &axis::ContinuousAxis, face_width: u32) -> HashMap<i32, f64> {
     axis.ticks()
         .iter()
         .map(|&tick| (value_to_axis_cell_offset(tick, axis, face_width), tick))
@@ -33,7 +32,7 @@ fn tick_offset_map(axis: &axis::Axis, face_width: u32) -> HashMap<i32, f64> {
 /// create a mapping of cell offset to bin bound
 fn bound_cell_offsets(
     hist: &histogram::Histogram,
-    x_axis: &axis::Axis,
+    x_axis: &axis::ContinuousAxis,
     face_width: u32,
 ) -> Vec<i32> {
     hist.bin_bounds
@@ -123,14 +122,13 @@ fn create_x_axis_labels(x_tick_map: &HashMap<i32, f64>) -> Vec<XAxisLabel> {
         .iter()
         .map(|(&offset, &tick)| XAxisLabel {
             text: tick.to_string(),
-            offset: offset,
-        })
-        .collect();
+            offset,
+        }).collect();
     ls.sort_by_key(|l| l.offset);
     ls
 }
 
-pub fn render_y_axis_strings(y_axis: &axis::Axis, face_height: u32) -> (String, i32) {
+pub fn render_y_axis_strings(y_axis: &axis::ContinuousAxis, face_height: u32) -> (String, i32) {
     // Get the strings and offsets we'll use for the y-axis
     let y_tick_map = tick_offset_map(y_axis, face_height);
 
@@ -153,16 +151,14 @@ pub fn render_y_axis_strings(y_axis: &axis::Axis, face_height: u32) -> (String,
         .map(|line| match y_tick_map.get(&(line as i32)) {
             Some(v) => v.to_string(),
             None => "".to_string(),
-        })
-        .collect();
+        }).collect();
 
     // Generate a list of strings to tick the y-axis
     let y_tick_strings: Vec<_> = (0..face_height + 1)
         .map(|line| match y_tick_map.get(&(line as i32)) {
             Some(_) => "-".to_string(),
             None => " ".to_string(),
-        })
-        .collect();
+        }).collect();
 
     // Generate a list of strings to be the y-axis line itself
     let y_axis_line_strings: Vec<String> = std::iter::repeat('+')
@@ -178,7 +174,8 @@ pub fn render_y_axis_strings(y_axis: &axis::Axis, face_height: u32) -> (String,
         .zip(y_axis_line_strings.iter())
         .map(|(((a, x), y), z)| (a, x, y, z));
 
-    let axis_string: Vec<String> = iter.rev()
+    let axis_string: Vec<String> = iter
+        .rev()
         .map(|(l, ls, t, a)| {
             format!(
                 "{} {:>num_width$}{}{}",
@@ -188,15 +185,14 @@ pub fn render_y_axis_strings(y_axis: &axis::Axis, face_height: u32) -> (String,
                 a,
                 num_width = longest_y_label_width
             )
-        })
-        .collect();
+        }).collect();
 
     let axis_string = axis_string.join("\n");
 
     (axis_string, longest_y_label_width as i32)
 }
 
-pub fn render_x_axis_strings(x_axis: &axis::Axis, face_width: u32) -> (String, i32) {
+pub fn render_x_axis_strings(x_axis: &axis::ContinuousAxis, face_width: u32) -> (String, i32) {
     // Get the strings and offsets we'll use for the x-axis
     let x_tick_map = tick_offset_map(x_axis, face_width as u32);
 
@@ -205,8 +201,7 @@ pub fn render_x_axis_strings(x_axis: &axis::Axis, face_width: u32) -> (String, i
         .map(|cell| match x_tick_map.get(&(cell as i32)) {
             Some(_) => '|',
             None => ' ',
-        })
-        .collect();
+        }).collect();
 
     // Create a string which will be printed to give the x-axis labels
     let x_labels = create_x_axis_labels(&x_tick_map);
@@ -277,8 +272,8 @@ pub fn render_x_axis_strings(x_axis: &axis::Axis, face_width: u32) -> (String, i
 /// create the strings to be drawn as the face
 pub fn render_face_bars(
     h: &histogram::Histogram,
-    x_axis: &axis::Axis,
-    y_axis: &axis::Axis,
+    x_axis: &axis::ContinuousAxis,
+    y_axis: &axis::ContinuousAxis,
     face_width: u32,
     face_height: u32,
 ) -> String {
@@ -291,11 +286,8 @@ pub fn render_face_bars(
         .iter()
         .map(|&bin| match bin {
             None => 0,
-            Some(b) => {
-                value_to_axis_cell_offset(h.bin_counts[b as usize] as f64, y_axis, face_height)
-            }
-        })
-        .collect();
+            Some(b) => value_to_axis_cell_offset(h.get_values()[b as usize], y_axis, face_height),
+        }).collect();
 
     let mut face_strings: Vec<String> = vec![];
 
@@ -352,9 +344,9 @@ pub fn render_face_bars(
 /// and the face height and width,
 /// create the strings to be drawn as the face
 pub fn render_face_points<S>(
-    s: &scatter::Scatter,
-    x_axis: &axis::Axis,
-    y_axis: &axis::Axis,
+    s: &[(f64, f64)],
+    x_axis: &axis::ContinuousAxis,
+    y_axis: &axis::ContinuousAxis,
     face_width: u32,
     face_height: u32,
     style: &S,
@@ -362,15 +354,14 @@ pub fn render_face_points<S>(
 where
     S: style::Point,
 {
-    let points: Vec<_> = s.data
+    let points: Vec<_> = s
         .iter()
         .map(|&(x, y)| {
             (
                 value_to_axis_cell_offset(x, x_axis, face_width),
                 value_to_axis_cell_offset(y, y_axis, face_height),
             )
-        })
-        .collect();
+        }).collect();
 
     let marker = match style.get_marker().clone().unwrap_or(style::Marker::Circle) {
         style::Marker::Circle => '●',
@@ -458,8 +449,7 @@ pub fn overlay(under: &str, over: &str, x: i32, y: i32) -> String {
                 l.chars()
                     .chain((0..line_width_deficit).map(|_| ' '))
                     .collect()
-            })
-            .collect()
+            }).collect()
     } else {
         split_over
     };
@@ -535,7 +525,7 @@ mod tests {
     #[test]
     fn test_value_to_axis_cell_offset() {
         assert_eq!(
-            value_to_axis_cell_offset(3.0, &axis::Axis::new(5.0, 10.0), 10),
+            value_to_axis_cell_offset(3.0, &axis::ContinuousAxis::new(5.0, 10.0), 10),
             -4
         );
     }
@@ -577,7 +567,7 @@ mod tests {
 
     #[test]
     fn test_render_y_axis_strings() {
-        let y_axis = axis::Axis::new(0.0, 10.0);
+        let y_axis = axis::ContinuousAxis::new(0.0, 10.0);
 
         let (y_axis_string, longest_y_label_width) = render_y_axis_strings(&y_axis, 10);
 
@@ -589,7 +579,7 @@ mod tests {
 
     #[test]
     fn test_render_x_axis_strings() {
-        let x_axis = axis::Axis::new(0.0, 10.0);
+        let x_axis = axis::ContinuousAxis::new(0.0, 10.0);
 
         let (x_axis_string, start_offset) = render_x_axis_strings(&x_axis, 20);
 
@@ -603,9 +593,9 @@ mod tests {
     #[test]
     fn test_render_face_bars() {
         let data = vec![0.3, 0.5, 6.4, 5.3, 3.6, 3.6, 3.5, 7.5, 4.0];
-        let h = histogram::Histogram::from_vec(&data, 10);
-        let x_axis = axis::Axis::new(0.3, 7.5);
-        let y_axis = axis::Axis::new(0., 3.);
+        let h = histogram::Histogram::from_slice(&data, histogram::Bins::Count(10));
+        let x_axis = axis::ContinuousAxis::new(0.3, 7.5);
+        let y_axis = axis::ContinuousAxis::new(0., 3.);
         let strings = render_face_bars(&h, &x_axis, &y_axis, 20, 10);
         assert_eq!(strings.lines().count(), 10);
         assert!(strings.lines().all(|s| s.chars().count() == 20));
@@ -628,6 +618,7 @@ mod tests {
 
     #[test]
     fn test_render_face_points() {
+        use crate::scatter;
         let data = vec![
             (-3.0, 2.3),
             (-1.6, 5.3),
@@ -636,11 +627,11 @@ mod tests {
             (6.4, 4.3),
             (8.5, 3.7),
         ];
-        let s = scatter::Scatter::from_vec(&data);
-        let x_axis = axis::Axis::new(-3.575, 9.075);
-        let y_axis = axis::Axis::new(-1.735, 5.635);
+        let s = scatter::Scatter::from_slice(&data);
+        let x_axis = axis::ContinuousAxis::new(-3.575, 9.075);
+        let y_axis = axis::ContinuousAxis::new(-1.735, 5.635);
         let style = scatter::Style::new();
-        let strings = render_face_points(&s, &x_axis, &y_axis, 20, 10, &style);
+        let strings = render_face_points(&s.data, &x_axis, &y_axis, 20, 10, &style);
         assert_eq!(strings.lines().count(), 10);
         assert!(strings.lines().all(|s| s.chars().count() == 20));
 
